@@ -32,6 +32,7 @@ const (
 	CleanupFull = "full"
 	CleanupLog  = "log"
 	CleanupTmp  = "tmp"
+	CleanupLock = "lock"
 )
 
 var DryRun *bool
@@ -75,6 +76,15 @@ func redoDirClean(root, what string) error {
 						}
 					}
 				}
+			case CleanupLock:
+				if strings.HasSuffix(fi.Name(), LockSuffix) {
+					fmt.Println(pth)
+					if !*DryRun {
+						if err = os.Remove(pth); err != nil {
+							return err
+						}
+					}
+				}
 			case CleanupTmp:
 				if strings.HasPrefix(fi.Name(), TmpPrefix) {
 					fmt.Println(pth)
