@@ -100,7 +100,7 @@ func depWrite(fdDep *os.File, cwd, tgt, hsh string) error {
 	if fi.IsDir() {
 		return nil
 	}
-	inode, err := inodeFromFile(fd)
+	inode, err := inodeFromFileByFd(fd)
 	if err != nil {
 		return err
 	}
