@@ -121,7 +121,7 @@ func depFix(root string) error {
 					}
 					return err
 				}
-				inode, err := inodeFromFile(fd)
+				inode, err := inodeFromFileByFd(fd)
 				if err != nil {
 					fd.Close()
 					return err
