@@ -179,6 +179,17 @@ RebuildDeps:
 }
 
 func ifchange(tgts []string, forced, traced bool) (bool, error) {
+	// only unique elements
+	m := make(map[string]struct{})
+	for _, t := range tgts {
+		m[t] = struct{}{}
+	}
+	tgts = tgts[:0]
+	for t := range m {
+		tgts = append(tgts, t)
+	}
+	m = nil
+
 	jsInit()
 	if !IsTopRedo {
 		defer jsAcquire("ifchange exiting")
