@@ -25,7 +25,6 @@ import (
 	"flag"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"log"
 	"os"
 	"os/signal"
@@ -216,14 +215,14 @@ func main() {
 	tracef(CDebug, "inode-trust: %s", InodeTrust)
 
 	// Those are internal envs
-	FdOODTgts, err = ioutil.TempFile("", "ood-tgts")
+	FdOODTgts, err = os.CreateTemp("", "ood-tgts")
 	if err != nil {
 		log.Fatalln(err)
 	}
 	if err = os.Remove(FdOODTgts.Name()); err != nil {
 		log.Fatalln(err)
 	}
-	FdOODTgtsLock, err = ioutil.TempFile("", "ood-tgts.lock")
+	FdOODTgtsLock, err = os.CreateTemp("", "ood-tgts.lock")
 	if err != nil {
 		log.Fatalln(err)
 	}
@@ -244,7 +243,7 @@ func main() {
 		if _, err = fd.Seek(0, io.SeekStart); err != nil {
 			log.Fatalln(err)
 		}
-		tgtsRaw, err := ioutil.ReadAll(bufio.NewReader(fd))
+		tgtsRaw, err := io.ReadAll(bufio.NewReader(fd))
 		if err != nil {
 			log.Fatalln(err)
 		}
@@ -390,7 +389,7 @@ CmdSwitch:
 			log.Fatalln("single target expected")
 		}
 		var fdTmp *os.File
-		fdTmp, err = ioutil.TempFile("", "whichdo")
+		fdTmp, err = os.CreateTemp("", "whichdo")
 		if err != nil {
 			break
 		}
