@@ -24,7 +24,7 @@ import (
 )
 
 const (
-	Version  = "1.27.1"
+	Version  = "1.28.0"
 	Warranty = `Copyright (C) 2020-2022 Sergey Matveev
 
 This program is free software: you can redistribute it and/or modify
@@ -62,10 +62,10 @@ Record ifcreate dependency for current target. Unusable outside .do.`
 
 Always build current target. Unusable outside .do.`
 	case CmdNameRedoCleanup:
-		d = `Usage: redo-cleanup [-n] {full,log,tmp} [...]
+		d = `Usage: redo-cleanup [-n] {full,log,lock,tmp} [...]
 
-Remove either all goredo's related temporary files, or kept stderr
-logs, or everything (including .redo directories) related.`
+Remove either all of goredo's related temporary files, or kept stderr
+logs, or lock files, or everything (including .redo directories) related.`
 	case CmdNameRedoLog:
 		d = `Usage: redo-log [-c] [-r] target [ | tai64nlocal ]
 
